@@ -23,14 +23,14 @@ from .resultitem import ResultItem
 from .preferences import CurtailPrefsWindow
 from .compressor import Compressor
 from .tools import add_filechooser_filters, get_file_type, \
-    create_image_from_file, sizeof_fmt, debug_infos
+    create_image_from_file, sizeof_fmt, debug_infos, get_image_files_from_folder
 
 CURTAIL_PATH = '/com/github/huluti/Curtail/'
 SETTINGS_SCHEMA = 'com.github.huluti.Curtail'
 
 
 @Gtk.Template(resource_path=CURTAIL_PATH + 'ui/window.ui')
-class CurtailWindow(Gtk.ApplicationWindow):
+class CurtailWindow(Adw.ApplicationWindow):
     __gtype_name__ = 'CurtailWindow'
 
     _settings = Gio.Settings.new(SETTINGS_SCHEMA)
@@ -104,6 +104,7 @@ class CurtailWindow(Gtk.ApplicationWindow):
         self.create_simple_action('preferences', self.on_preferences, '<Primary>comma')
         self.create_simple_action('about', self.on_about)
         self.create_simple_action('quit', self.on_quit, '<Primary>q')
+        self.create_simple_action('convert-dir', self.on_select_folder, '<Primary>d')
 
     def enable_compression(self, enable):
         self.filechooser_button_headerbar.set_sensitive(enable)
@@ -140,7 +141,8 @@ class CurtailWindow(Gtk.ApplicationWindow):
 
         if len(result_item.new_filename) > 0:
             image = create_image_from_file(result_item.filename, 48, 48)
-            row.add_prefix(image)
+            if image:
+                row.add_prefix(image)
 
         savings_widget = Gtk.Label()
         savings_widget.add_css_class('success')
@@ -200,6 +202,57 @@ class CurtailWindow(Gtk.ApplicationWindow):
 
         dialog.open_multiple(self, None, handle_response)
 
+    def on_select_folder(self, *args):
+        dialog = Gtk.FileDialog(title=_("Browse Directories"))
+
+        def handle_response(dialog, result):
+            def on_dir_dialog_response(warn_dialog, response):
+                if response == "compress":
+                    filenames = list()
+                    for folder in folders:
+                        images = get_image_files_from_folder(folder.get_path())
+
+                        for image in images:
+                            filenames.append(image.get_uri())
+
+                    final_filenames = self.handle_filenames(filenames)
+                    self.compress_filenames(final_filenames)
+
+            try:
+                folders = dialog.select_multiple_folders_finish(result)
+            except GLib.Error as err:
+                print("Could not open files: %s", err.message)
+            else:
+                warning_message_dialog = self._create_warning_dialog()
+                warning_message_dialog.connect("response", on_dir_dialog_response)
+                warning_message_dialog.show()
+
+        dialog.select_multiple_folders(self, None, handle_response)
+
+    def _create_warning_dialog(self):
+        dialog = None
+        if self._settings.get_boolean('new-file'):
+            dialog = Adw.MessageDialog.new(self,
+                _("Are you sure you want to compress images in these directories?"),
+                _("All of the images in the directories selected and their "
+                "subdirectories will be compressed. The original images will not "
+                "be modified."))
+        else:
+            dialog = Adw.MessageDialog.new(self,
+                _("Are you sure you want to compress images in these directories?"),
+                _("All of the images in the directories selected and their "
+                "subdirectories will be compressed and overwritten!"))
+
+        dialog.add_response("cancel", _("Cancel"))
+        dialog.add_response("compress", _("Compress"))
+
+        if self._settings.get_boolean('new-file'):
+            dialog.set_response_appearance("compress", Adw.ResponseAppearance.SUGGESTED)
+        else:
+            dialog.set_response_appearance("compress", Adw.ResponseAppearance.DESTRUCTIVE)
+
+        return dialog
+
     def on_dnd_drop(self, drop_target, value, x, y, user_data=None):
         files = value.get_files()
         if not files:
@@ -309,7 +362,7 @@ class CurtailWindow(Gtk.ApplicationWindow):
                     license_type=Gtk.License.GPL_3_0,
                     website='https://github.com/Huluti/Curtail',
                     issue_url='https://github.com/Huluti/Curtail/issues/new',
-                    version='1.7.0',
+                    version='1.8.0',
                     developers=[
                         'Hugo Posnic https://github.com/Huluti'
                     ],
